package com.ruoyi.asset.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.asset.domain.TbAssetInformation;
import com.ruoyi.asset.service.ITbAssetInformationService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 资产信息Controller
 * 
 * @author 原动力
 * @date 2023-05-15
 */
@RestController
@RequestMapping("/asset/information")
public class TbAssetInformationController extends BaseController
{
    @Autowired
    private ITbAssetInformationService tbAssetInformationService;

    /**
     * 查询资产信息列表
     */
    @PreAuthorize("@ss.hasPermi('asset:information:list')")
    @GetMapping("/list")
    public TableDataInfo list(TbAssetInformation tbAssetInformation)
    {
        startPage();
        List<TbAssetInformation> list = tbAssetInformationService.selectTbAssetInformationList(tbAssetInformation);
        return getDataTable(list);
    }

    /**
     * 导出资产信息列表
     */
    @PreAuthorize("@ss.hasPermi('asset:information:export')")
    @Log(title = "资产信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TbAssetInformation tbAssetInformation)
    {
        List<TbAssetInformation> list = tbAssetInformationService.selectTbAssetInformationList(tbAssetInformation);
        ExcelUtil<TbAssetInformation> util = new ExcelUtil<TbAssetInformation>(TbAssetInformation.class);
        util.exportExcel(response, list, "资产信息数据");
    }

    /**
     * 获取资产信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('asset:information:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tbAssetInformationService.selectTbAssetInformationById(id));
    }

    /**
     * 新增资产信息
     */
    @PreAuthorize("@ss.hasPermi('asset:information:add')")
    @Log(title = "资产信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TbAssetInformation tbAssetInformation)
    {
        return toAjax(tbAssetInformationService.insertTbAssetInformation(tbAssetInformation));
    }

    /**
     * 修改资产信息
     */
    @PreAuthorize("@ss.hasPermi('asset:information:edit')")
    @Log(title = "资产信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TbAssetInformation tbAssetInformation)
    {
        return toAjax(tbAssetInformationService.updateTbAssetInformation(tbAssetInformation));
    }

    /**
     * 删除资产信息
     */
    @PreAuthorize("@ss.hasPermi('asset:information:remove')")
    @Log(title = "资产信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tbAssetInformationService.deleteTbAssetInformationByIds(ids));
    }
}
